@@ -1,8 +1,9 @@
-__version__ = '1.0.0'
+__version__ = "1.0.4"
 
 from .tm_player_data import tm_player_data
 from .tm_player_metadata import tm_player_metadata
 from .tm_player_market_value import tm_player_market_value
 from .tm_player_transfers import tm_player_transfers
 from .tm_player_injury import tm_player_injury
-from .tm_team_player_urls import tm_team_player_urls
\ No newline at end of file
+from .tm_team_player_urls import tm_team_player_urls
+from .tm_team_transfers import tm_team_transfers
